@@ -35,6 +35,7 @@ RegionWindow::RegionWindow(QMainWindow *parent) : SettingsWindow(parent), FLAGPA
 	MyToolButton *zaButton = new MyToolButton(QIcon(QString(FLAGPATH) + "za.png"), "ZA", this);
 	MyToolButton *plButton = new MyToolButton(QIcon(QString(FLAGPATH) + "pl.png"), "PL", this);
 	MyToolButton *fiButton = new MyToolButton(QIcon(QString(FLAGPATH) + "fi.png"), "FI", this);
+	MyToolButton *ieButton = new MyToolButton(QIcon(QString(FLAGPATH) + "ie.png"), "IE", this);
 
 	QGridLayout *finallayout = new QGridLayout;
 	finallayout->addWidget(ukButton,0,0);
@@ -56,6 +57,7 @@ RegionWindow::RegionWindow(QMainWindow *parent) : SettingsWindow(parent), FLAGPA
 	finallayout->addWidget(zaButton,5,1);
 	finallayout->addWidget(plButton,5,2);
 	finallayout->addWidget(fiButton,6,0);
+	finallayout->addWidget(ieButton,6,1);
 
 	widget->setLayout(finallayout);
 
@@ -85,6 +87,7 @@ RegionWindow::RegionWindow(QMainWindow *parent) : SettingsWindow(parent), FLAGPA
 	connect(zaButton, SIGNAL(clicked()), this, SLOT(setZA()));
 	connect(plButton, SIGNAL(clicked()), this, SLOT(setPL()));
 	connect(fiButton, SIGNAL(clicked()), this, SLOT(setFI()));
+	connect(ieButton, SIGNAL(clicked()), this, SLOT(setIE()));
 	
 	loadSettings();
 }
@@ -172,6 +175,11 @@ void RegionWindow::setFI()
 {
     setRegion("FI");
 }
+void RegionWindow::setIE()
+{
+    setRegion("IE");
+}
+
 
 
 RegionWindow::~RegionWindow()
