@@ -37,7 +37,7 @@ public:
 	QStringList getRegionList()
 	{
 		QStringList list;
-		list << "UK" << "AU" << "NZ" << "SE" << "DE" << "FR" << "ES" << "IT" << "HR" << "SI" << "DK" << "NL" << "BE" << "NO" << "RU" << "MY" << "ZA" << "PL" << "FI";
+		list << "UK" << "AU" << "NZ" << "SE" << "DE" << "FR" << "ES" << "IT" << "HR" << "SI" << "DK" << "NL" << "BE" << "NO" << "RU" << "MY" << "ZA" << "PL" << "FI" << "IE";
 		return list;
 	}
 
@@ -63,6 +63,7 @@ private slots:
 	void setZA();
 	void setPL();
 	void setFI();
+	void setIE();
 	void setRegion(QString region);
 
 signals:
